* Figure 4.2
clear all
set more off

// Millienium Cohort Study 

// Panel a: education level 
use data_mcs_second.dta

* label main variable
label variable edu_fs "Academic Qualification (1: Highest)"

* drop those without education response
drop if edu_fs == . 

* compute the mean across respondents for each response 
collapse (mean) firmrulesanddiscipline lotsoffun readeveryday thinkforhimherself workhard obeyparents, by(edu_fs)

graph twoway (line obeyparents edu_fs, lcolor(black) lwidth(medthick)), ///
legend(off) xlabel(1(1)6, labsize(medlarge)) ///
ylabel(, labsize(medlarge)) ytitle("Fraction of Parents Valuing Obedience", size(medlarge) height(5)) ///
 xtitle("Highest academic qualification", size(medlarge)  height(5)) xscale(reverse) graphregion(color(white))
graph save "edu_obeyparents", replace

// Panel b: social class 
use data_mcs_second.dta, clear

* label main variable
rename ns_sec_8 ns_sec
label variable ns_sec "Social Class"

* drop non-respondents to social class variable
drop if ns_sec == .

* drop unemployed, students, not stated and not classifiable
drop if ns_sec == 8 | ns_sec == 9 | ns_sec == 10 | ns_sec == 11

* compute the mean across respondents for each response 
collapse (mean) firmrulesanddiscipline lotsoffun readeveryday thinkforhimherself workhard obeyparents, by(ns_sec)


graph twoway (line obeyparents ns_sec, lcolor(black) lwidth(medthick)), ///
legend(off) xlabel(1(1)7, labsize(medlarge)) ylabel(, labsize(medlarge)) ///
ytitle("Fraction of Parents Valuing Obedience", size(medlarge) height(5)) xtitle("Social class", size(medlarge) height(5)) xscale(reverse) graphregion(color(white)) 
graph save "occ_obeyparents", replace


// Panel c: family income (banded)
use "data_mcs_second.dta", clear

* label main variable
lab var BDHINC00 "Family income (1,000 pounds)"

* drop non-respondents to social class variable
drop if BDHINC00 == .

* compute the mean across respondents for each response 
collapse (mean) firmrulesanddiscipline lotsoffun readeveryday thinkforhimherself workhard obeyparents, by(BDHINC00)

graph twoway (line obeyparents BDHINC00, lcolor(black) lwidth(medthick)), ///
xlabel(1 "0" 2 "10" 3 "20" 4 "30" 5 "45" 6 "55+", labsize(medlarge)) ///
ylabel(, labsize(medlarge)) ytitle("") ytitle("Fraction of Parents Valuing Obedience", size(medlarge) height(5)) xtitle("Family income (1,000 pounds)", size(medlarge) height(5)) legend(off) graphregion(color(white)) 
graph save "inc_obeyparents", replace

// Combine graphs
graph combine "edu_obeyparents" "occ_obeyparents" "inc_obeyparents", cols(3) rows(1) ysize(3) xsize(6) graphregion(color(white))
graph save figure4_2.gph, replace

