* Figure 4.4
clear all
set more off

// Using GSS data

* Keep only certain GSS variables (see variable labels for definitions): 
use year age  childs educ degree  hompop babies preteen teens  rincome spanking if year>=1986 using GSS7214_R3.DTA , clear

* Clean Data Set
drop if spanking==.i | spanking==.n /* missing\na drop, keep response dk = dont know */

* Create New Variables
gen kids = 0
replace kids = 1 if babies>0 | preteen>0  /* household with kids under 17 == 1*/

* Spanking variables dont sum to population because there is still "dont know" category
gen spank = 0
replace spank = 1 if spanking == 1 | spanking == 2

gen nospank = 0
replace nospank = 1 if spanking ==3 | spanking == 4

* create the 3 education categories:
gen edu3 = 0
replace edu3 = 1 if degree==1 | degree==0 /*HS or less*/
replace edu3 = 2 if degree==2 | degree==3 /*Associates or BA*/
replace edu3 = 3 if degree==4 /*Graduate*/

* compute the share approving of spanking in each educ group
bys year edu3: gen nedu3 = _N
bys year edu3: egen spank_edu3 = total(spank)
replace spank_edu3 = spank_edu3/nedu3

* add 1968 datapoint:
append using "WP_SOV1968_Datapoint.dta"

* One Panel Graph, Year Bin Linear Trends
* Create 5-year Bin Averages
* drop non-response: 
drop if edu3==.

* compute the averages by year, education level:
collapse (mean) agree_spank=spank_edu3, by(year edu3)
reshape wide agree_spank, i(year) j(edu3) 

* Create Bin Plot Variables
gen year5  = . 
gen spank5yr1 = . 
gen spank5yr2 = . 
gen spank5yr3 = . 

replace year5   = 1967.5 if year>=1965 & year<1970
replace year5   = 1987.5 if year>=1985 & year<1990
replace year5   = 1992.5 if year>=1990 & year<1995
replace year5   = 1997.5 if year>=1995 & year<2000
replace year5   = 2002.5 if year>=2000 & year<2005
replace year5   = 2007.5 if year>=2005 & year<2010
replace year5   = 2012.5 if year>=2010 & year<2015

* collapse data to 5 year bins
collapse (mean) agree_*, by(year5) 

label var year5 "Year"
label var agree_spank3 "Graduate"
label var agree_spank2 "Associates or BA"
label var agree_spank1 "High School or Less"

*Convert responses to percentages
replace agree_spank3 = agree_spank3*100
replace agree_spank2 = agree_spank2*100
replace agree_spank1 = agree_spank1*100

twoway (line agree_spank3 year5, lp(solid) lc(black)) ///
(line agree_spank2 year5, lp(dash) lc(black)) ///
(line agree_spank1 year5, lp(longdash) lc(black)), ///
legend(rows(1)) ysc(r(50 100)) ylab(50(10)100) xsc(r(1965 2015)) ///
 xlabel(1965(10)2015) ytitle("Approval of spanking (%)", height(4)) graphregion(color(white)) 

graph save figure4_4.gph, replace


