* Numbers for Chapter 4
clear all 
set more off

* Upward mobility, NLSY p. 132 probability of post-grad degree 
use DZ_DATA_NLSY97.dta, clear

* Additional Cleaning:
* Change all -4, valid skips, to NaN
* All negative numbers are codes for skip sequence
foreach v of varlist _all { 
	replace `v'=. if `v'<0
} 

* Rename Important Variables
rename KEY_ETHNICITY ethnicity
rename KEY_RACE_1997 race
rename KEY_AGEDOL_1997 age1997
rename KEY_SEX_1997 sex
rename CV_HGC_RES_DAD edu_dad //highest grade completed by residential father, not biological
rename CV_HGC_RES_MOM edu_mom
rename FP_YMPSTYL_1997 pstyle_mom // residential mother parenting style in 1997, round 1 interview
rename FP_YFPSTYL_1997 pstyle_dad 
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg //R's highest degree ever received by 2013
rename CV_HH_NET_WORTH_P hh_net_worth_1997 // household networth in 1997, as reported by parents
rename SAMPLING_WEIGHT_CC_1997 sampw //sampling weights
rename TRANS_CRD_GPA_OVERALL GPA

 * Adjusting Variables
replace GPA = GPA/100 //GPA has two implied decimal places

* Adjust Labels
label def hisplabs 0 "Not Hispanic" 1 "Hispanic"
label values ethnicity hisplabs

* Cleaning Education
* NOTE: Education top coded at "20" for 8 years of college or more 
replace R_edu=. if R_edu==95      //95 codes ungraded schooling
replace edu_dad =. if edu_dad==95
replace edu_mom =. if edu_mom==95

label variable edu_mom "Mother's Edu"
label variable edu_dad "Father's Edu"

gen age = age1997 + 2013-1997 
gen age2 = age^2

gen ppba = . // post-BA degree
replace ppba = 1 if R_deg>4
replace ppba = 0 if R_deg<=4
label variable ppba "Post-BA Degree"

* Linear Models Probability Model of Post-BA Attainment
reg ppba ib(1).pstyle_mom ib(1).pstyle_dad age age2
reg ppba ib(1).pstyle_mom ib(1).pstyle_dad age age2 edu_mom edu_dad
reg ppba ib(1).pstyle_mom ib(1).pstyle_dad age age2 edu_mom edu_dad ib(1).race ib(0).ethnicity i.sex
reg ppba ib(1).pstyle_mom ib(1).pstyle_dad age age2 edu_mom edu_dad ib(1).race ib(0).ethnicity i.sex CV_INCOME_GROSS_YR_1997

* Linear Models of Educational Attainment, both parents 
* SET (3): Both Parents
reg R_edu ib(1).pstyle_mom ib(1).pstyle_dad 
reg R_edu ib(1).pstyle_mom ib(1).pstyle_dad  edu_mom edu_dad  
reg R_edu ib(1).pstyle_mom ib(1).pstyle_dad  edu_mom edu_dad ib(1).race ib(0).ethnicity i.sex age age2 

********************* BHPS Regressions on Upward Mobility p. 135 **********************
*Use cleaned BHPS child-level panel with parent characteristics
set more off 
use pid year data  strict_* inv_* child_youth_ypdoby4 child_adult_indresp_jbgold	child_adult_indresp_qfedhi using youth_adult_parents_bhps_rec if dataset=="indresp_bhps", clear

*we start with using the last available parenting style responses from 
*youth participants: 
order pid data strict_* inv_*	
keep if dataset=="indresp_bhps" // survey responses

* from these individuals we use the last available results from the adult survey
order year
bysort pid: egen maxyear=max(year)
keep if year==maxyear // latest available

* create class var of child based on goldthorpe (see text for more)
gen childclass= child_adult_indresp_jbgold 
rename child_adult_indresp_qfedhi child_edu

* change missing numeric codes to stata missing: 
mvdecode childclass child_edu,  mv(-9, -8, -7, -3)
* collapse education categories: 
recode child_edu (1/2=1)(3/4=2)(5/6=3), gen(child_edu3)
* collapse class categories: 
recode childclass (1=1)(2=2)(3/4=3)(5/7=4)(8=5)(9=6)(10/11=7), gen(child_7class)

* add data on parent social class and education and parenting styles 
sort pid
merge 1:1 pid using masterdata
drop if _merge==2
drop _merge

gen age_job= year-child_youth_ypdoby4

* parenting styles: 
tabulate lc3class, generate(parenting_)
rename parenting_1 authoritative 
rename parenting_2 authoritarian 
rename parenting_3 other 

*---------  goldthorpe 7
* we start with the goldthorpe 7 categories classification
*first lets rank categories according to the average education level
*use parents for this (older)
*variable "edu" from CK: 1=degree, 6=no qualification
*similar coding for fathers (dadqual) and mothers (momqual)

bysort dad7class: egen av_educ_father_7=mean(dadqual)
sort av_educ_father_7
tab  av_educ_father_7 dad7class
*except for the self-employed, which have the lowest educational attainment on average, 
*education decreases with class coding

bysort mum7class: egen av_educ_mother_7=mean(mumqual)
sort av_educ_mother_7
tab  av_educ_mother_7 mum7class
*the general negative correlation between class coding and education persists,
*however above anomaly for self-employed did not

*how about CKs measures for education and class?
*increases sample size, as it aggregates father and mother information, cf. above)
tab class7 edu
bysort class7: egen av_edu_7=mean(edu)
tab av_edu_7 class7

*lets recode along this lines:
gen child_class7_old=child_7class 
gen parent_class7_old=class7 
recode class7 (1=1)(2=2)(3=3)(5=4)(6=5)(4=6)(7=7), gen(parent_class7_educranked)
recode child_7class (1=1)(2=2)(3=3)(5=4)(6=5)(4=6)(7=7), gen(child_class7_educranked)

tab parent_class7_educ av_edu_7
tab parent_class7_educ child_class7_educ, row
*high persistence in classes 2, 3 and 7, low in class 1, 6 and 4 
*this also reflects the fact, that one has to reach a certain age to end up in 
*classes such as 1 (higher salariat) or 6 (self-employed)

*define occupational mobility (see text for more)
gen occ_mobility_7=1
replace occ_mobility_7=0 if parent_class7_educ==child_class7_educ

gen upwardmob=0
*NOTE: 	Higher class value, lower class -ie. 1 is highest, 7 lowest
*		in terms of educational content
replace upwardmob=1 if parent_class7_educ>child_class7_educ
replace upwardmob=. if parent_class7_educ==.|child_class7_educ==.
*upwardmob=1 -> children experienced upward mobility

* Need to remove highest class because no upward mobility possible there
xi:reg upwardmob authoritative authoritarian i.parent_class7_educ age_job if parent_class7_educ>1, rob 

* Now look for larger jumps in social class

gen upwardmob_big=0
*NOTE: 	Higher class value, lower class -ie. 1 is highest, 7 lowest
*		in terms of educational content
replace upwardmob_big=1 if parent_class7_educ>child_class7_educ+1
replace upwardmob_big=. if parent_class7_educ==.|child_class7_educ==.
*upwardmob_big=1 -> children experienced upward mobility by 2 classes or more
tab upwardmob_big parent_class7_educ

* REGRESSION, conditional on parental education and class 
xi:reg upwardmob_big authoritative authoritarian i.parent_class7_educ age_job if parent_class7_educ>2, rob 

****************************************************************************
******************* NLSY Parenting Styles by Single Parenting Status (p. 136) 
* and Race (p. 142) 
****************************************************************************
set more off 
use DZ_DATA_NLSY97.dta, clear

* Additional Cleaning:
* Change all -4, valid skips, to NaN
* All negative numbers are codes for skip sequence
foreach v of varlist _all { 
	qui replace `v'=. if `v'<0
} 
*
* Identifying single parent homes:
* Using the household roster in 1997 I check to see if any member listed is identified as mother or father
* Each household is classified by the number of parents identified.
qui gen parents  =0
qui gen parents2 =0 //includes adoptive, step-, and foster parents that reside in the house
gen mom_age = .
gen dad_age = .
foreach i in _01 _02 _03 _04 _05 _06 _07 _08 _09 _10 _11 _12 _13 _14 _15 _16 _17 {

* Number of Parents
qui replace parents = parents+1 if HHI2_RELY`i'_1997==3 | HHI2_RELY`i'_1997==4 // 3 is mother, 4 is father
qui replace parents2 = parents2+1 if HHI2_RELY`i'_1997>=3 & HHI2_RELY`i'_1997<=10 // includes adoptive, foster, and step parents

* Age of Parents
qui replace mom_age = HHI2_AGE`i'_1997 if HHI2_RELY`i'_1997 == 3 | HHI2_RELY`i'_1997 == 5 | HHI2_RELY`i'_1997 == 7 | HHI2_RELY`i'_1997 == 9
qui replace dad_age = HHI2_AGE`i'_1997 if HHI2_RELY`i'_1997 == 4 | HHI2_RELY`i'_1997 == 6 | HHI2_RELY`i'_1997 == 8 | HHI2_RELY`i'_1997 == 10

}
*

* Single Motherhood
* NOTE: We recreate the above statistics for 1998 since degree of parent isnt available in 1997.
gen parents98 =0
gen parents98_2=0
gen mother_present = .
gen mother_present_2 = .
gen mom_degree98=.
gen dad_degree98=.
foreach i in _01 _02 _03 _04 _05 _06 _07 _08 _09 _10 _11 _12 _13 _14  {
* Number of Parents
qui replace parents98 = parents98+1 if HHI_RELY`i'_1998==3 | HHI_RELY`i'_1998==4 // 3 is mother, 4 is father
qui replace parents98_2 = parents98_2+1 if HHI_RELY`i'_1998>=3 & HHI_RELY`i'_1998<=10 // includes adoptive, foster, and step parents
qui replace mother_present   = 1 if HHI_RELY`i'_1998==3 
qui replace mother_present_2 = 1 if HHI_RELY`i'_1998==3  | HHI_RELY`i'_1998==5 | HHI_RELY`i'_1998==7 | HHI_RELY`i'_1998==9
* Degree of Residential Parents in 1998
qui replace mom_degree98 = HHI_DEGREE`i'_1998 if HHI_RELY`i'_1998 == 3 | HHI_RELY`i'_1998 == 5 | HHI_RELY`i'_1998 == 7 | HHI_RELY`i'_1998 == 9
qui replace dad_degree98 = HHI_DEGREE`i'_1998 if HHI_RELY`i'_1998 == 4 | HHI_RELY`i'_1998 == 6 | HHI_RELY`i'_1998 == 8 | HHI_RELY`i'_1998 == 10

}
*
* Define Single Motherhood
gen single_mother =.
replace single_mother = 1 if parents98_2==1 & mother_present_2==1 //single mother
replace single_mother = 0 if parents98_2==2 & mother_present_2==1 //two parent household

* Ignore household with three parents
replace parents98_2=. if parents98_2==3

* Assign Degree Labels 
qui label def pdeglabs 1 "None" 2 "GED" 3 "HS Diploma" 4 "Associates\Junior College" 5 "Bachelor's" 6 "Master's" 7 "Ph.D" 8 "Professional (DDs, JD, MD)"
qui label values mom_degree98 pdeglabs
qui label values dad_degree98 pdeglabs
qui label variable mom_degree "Residential Mother's Highest Degree"
qui label variable dad_degree "Residential Father's Highest Degree"

* Define Other Important Variables
rename KEY_ETHNICITY ethnicity
rename KEY_RACE_1997 race
rename KEY_AGEDOL_1997 age1997
rename KEY_SEX_1997 sex
rename CV_HGC_RES_DAD edu_dad //highest grade completed by residential father, not biological
rename CV_HGC_RES_MOM edu_mom
rename FP_YMPSTYL_1997 pstyle_mom // residential mother parenting style in 1997, round 1 interview
rename FP_YFPSTYL_1997 pstyle_dad 
rename FP_YMPSTYL_1998 pstyle_mom98 // residential mother parenting style in 1997, round 1 interview
rename FP_YFPSTYL_1998 pstyle_dad98 
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg //R's highest degree ever received by 2013
rename CV_HH_NET_WORTH_P hh_net_worth_1997 // household networth in 1997, as reported by parents
rename SAMPLING_WEIGHT_CC_1997 sampw //sampling weights
rename TRANS_CRD_GPA_OVERALL GPA

* Age variables for regressions
qui gen mom_age2 = mom_age^2
qui gen dad_age2 = dad_age^2 
gen age = age1997   
gen age2 = age^2
gen age_2013 = age1997 + 2013-1997 //child age in 2013 for education regressions
gen age2_2013 = age^2

* (1) Probability of being parenting style on basic controls and single/two parent indicator
* Regress parental style dummy on parental education (highest grade completed), age and age^2, and dummy for single parenthood
qui gen single_parent = 0
qui replace single_parent = 1 if parents2==1
qui replace single_parent = . if parents2==0 //no parents in this household

* Indicators of Parenting Style by Parent
qui gen d_mom_uninvolved    = . 
qui gen d_mom_permissive    = . 
qui gen d_mom_authoritarian = . 
qui gen d_mom_authoritative = . 

qui replace d_mom_uninvolved = 1 if pstyle_mom==1
qui replace d_mom_uninvolved = 0 if pstyle_mom~=1 & pstyle_mom~=.
qui replace d_mom_permissive    = 1 if pstyle_mom==2
qui replace d_mom_permissive = 0 if pstyle_mom~=2 & pstyle_mom~=.
qui replace d_mom_authoritarian = 1 if pstyle_mom==3
qui replace d_mom_authoritarian = 0 if pstyle_mom~=3 & pstyle_mom~=.
qui replace d_mom_authoritative = 1 if pstyle_mom==4
qui replace d_mom_authoritative = 0 if pstyle_mom~=4 & pstyle_mom~=.

* Parenting Styles of Single Mothers 
reg d_mom_uninvolved single_parent edu_mom mom_age mom_age2 
reg d_mom_permissive single_parent edu_mom mom_age mom_age2 
reg d_mom_authoritarian single_parent edu_mom mom_age mom_age2 
reg d_mom_authoritative single_parent edu_mom mom_age mom_age2 

* Parenting Style by Race/Ethnicity
tab race pstyle_mom , nofreq row
tab race pstyle_dad , nofreq row
tab ethnicity pstyle_mom , nofreq row // yes==hispanic
tab ethnicity pstyle_dad , nofreq row // yes==hispanic
