* Table 4.1, Doepke-Zilibotti
clear all 
set more off

/* This data is at the respondent (child) level. General approach of the do file is 
to create 3 datasets on parenting styles by parent's gender: all parents, 
mothers, and fathers. Because variable names differ by year, 1997 and 1998/2000
are dealt with separately in the creation of each dataset. 
*/

* Read in cleaned dataset

use "DZ_DATA_NLSY97.dta", clear

* Additional Cleaning:
* Change all -4, valid skips, to missing
* All negative numbers are codes for skip sequence
foreach v of varlist _all { 
	qui qui replace `v'=. if `v'<0
} 
*

* Create Mothers data file
tempfile maindat
save `maindat', replace

* 1997
* Keep only the necessary variables and standarize the variable names: 
keep CV_HGC_RES_MOM FP_YMPSTYL_1997 SAMPLING_WEIGHT_CC_1997 CVC_HGC_EVER_XRND CVC_HIGHEST_DEGREE_EVER_XRND
rename FP_YMPSTYL_1997 pstyle // parenting style variable, constructed from questions on supportiveness and strictness/demandingness
rename CV_HGC_RES_MOM pedu // mother's highest grade level
rename SAMPLING_WEIGHT_CC_1997 sampw // sampling weight
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg // respondents's highest degree ever received by 2013

gen year   = 1997
gen parent = 0 //mother

tempfile mtempdat //mothers
save `mtempdat', replace

forval i = 1998/2000{

use `maindat', clear

* variables are the same but for later years: 
keep CV_HGC_RES_MOM FP_YMPSTYL_`i' SAMPLING_WEIGHT_CC_`i' CVC_HGC_EVER_XRND CVC_HIGHEST_DEGREE_EVER_XRND
rename FP_YMPSTYL_`i' pstyle 
rename CV_HGC_RES_MOM pedu
rename SAMPLING_WEIGHT_CC_`i' sampw
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg //R's highest degree ever received by 2013

gen year   = `i'
gen parent = 0 //mother

append using `mtempdat'
save `mtempdat', replace

}
*
* Make Fathers database
use `maindat', clear

* variables are the same but for fathers: 
* 1997
keep CV_HGC_RES_DAD FP_YFPSTYL_1997 SAMPLING_WEIGHT_CC_1997 CVC_HGC_EVER_XRND CVC_HIGHEST_DEGREE_EVER_XRND
rename FP_YFPSTYL_1997 pstyle 
rename CV_HGC_RES_DAD pedu
rename SAMPLING_WEIGHT_CC_1997 sampw
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg //R's highest degree ever received by 2013


gen year   = 1997
gen parent = 1 //father

tempfile ftempdat //fathers
save `ftempdat', replace

forval i = 1998/2000{

use `maindat', clear
* variables are the same but for later years: 
keep CV_HGC_RES_DAD FP_YFPSTYL_`i' SAMPLING_WEIGHT_CC_`i' CVC_HGC_EVER_XRND CVC_HIGHEST_DEGREE_EVER_XRND
rename FP_YFPSTYL_`i' pstyle 
rename CV_HGC_RES_DAD pedu
rename SAMPLING_WEIGHT_CC_`i' sampw
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg //R's highest degree ever received by 2013

gen year   = `i'
gen parent = 1 //father

append using `ftempdat'
save `ftempdat', replace

}
*

* Combine Father and Mother databases
append using `mtempdat'

* Create Variables
gen pedu_01 = .
qui replace pedu_01 = 0 if pedu>=0  & pedu<=12 // high school or less
qui replace pedu_01 = 1 if pedu>12 & pedu<95   // more than HS

* Assign Labels
label define edulab 0 "Less Educated" 1 "More Educated"
label define plab   0 "Mother" 1 "Father"

label values parent plab
label values pedu_01 edulab
label variable pedu_01 "Parent's Education"
label variable parent "Parent"
label variable pstyle "Parenting Style"

drop if pstyle==.
drop if pedu  ==.



* Create Tables of Edu x Parenting Style
gen countdummy = 1
* sum the number of respondents with each style by year, gender, and education level:
collapse (count) countdummy [pw=sampw], by(parent pedu_01 year pstyle)
* compute percentages for the table for all genders:
bys year parent pedu_01: egen p_all = total(countdummy)
* round the value to the hundredth for the table:
gen pstyle_percent = round(100*countdummy/p_all,.01)



****************************** Table 4.1 ***************************************
* average over years to make the table:
collapse pstyle_percent, by(parent pedu_01 pstyle) // this is by gender (parent)
* round: 
qui replace pstyle_percent = round(pstyle_percent,.01)
* display the values for parent gender separately:
table pedu_01 pstyle parent, content(mean pstyle_percent)

collapse pstyle_percent, by(pedu_01 pstyle) // this is average for all parents (moms and dads)
* round: 
qui replace pstyle_percent = round(pstyle_percent,.01)
* display values for all parents: 
table pedu_01 pstyle, content(mean pstyle_percent)
