* Table 4.2, Doepke-Zilibotti
clear all 
set more off

use "DZ_DATA_NLSY97.dta", clear

* Additional Cleaning:
* Change all -4, valid skips, to NaN
* All negative numbers are codes for skip sequence
foreach v of varlist _all { 
	qui replace `v'=. if `v'<0
} 
*

* Naming Variables
rename FP_YMPSTYL_1997 pstyle_mom // mom parenting style 
rename FP_YFPSTYL_1997 pstyle_dad // dad parenting style 
rename FP_YMPSTYL_1998 pstyle_mom98 // diff varname for 1998, mom pstyle
rename FP_YFPSTYL_1998 pstyle_dad98 // diff varname for 1998, dad pstyle
rename CV_HGC_RES_MOM mom_edu       // mom education
rename CV_HGC_RES_DAD dad_edu       // dad education
rename SAMPLING_WEIGHT_CC_1997 sampw // sampling weight
rename CVC_HGC_EVER_XRND R_edu // respondent's (child's) highest grade completed by 2013
rename CVC_HIGHEST_DEGREE_EVER_XRND R_deg //respondent's highest degree ever received by 2013

* Parent Education, omit ungraded
replace mom_edu=. if mom_edu==95
replace dad_edu=. if dad_edu==95

* Household Education
gen hh_edu=.
qui replace hh_edu = 0 if (mom_edu>=0 & mom_edu<=12) & (dad_edu>=0 & dad_edu<=12) //both parents less educated
qui replace hh_edu = 1 if (mom_edu>=0 & mom_edu<=12) & (dad_edu>12 & dad_edu<95) // one parent more educated
qui replace hh_edu = 1 if (mom_edu>12 & mom_edu<95) & (dad_edu>=0 & dad_edu<=12) 
qui replace hh_edu = 2 if (mom_edu>12 & mom_edu<95) & (dad_edu>12 & dad_edu<95)   // both parents more educated

label define hhedulabs 0 "Both Parents Less Educated" 1 "One Parent More Educated" 2 "Both Parents More Educated", replace
label values hh_edu hhedulabs
label variable hh_edu "Parental Education"

*Youth Education
gen redu_01 = .
qui replace redu_01 = 0 if R_edu>=0  & R_edu<=12
qui replace redu_01 = 1 if R_edu>12 & R_edu<95


label define edulab 0 "Less Educated" 1 "More Educated", replace
label values redu_01 edulab
label variable redu_01 "Youth's Education" 

* HH_parenting style
gen pstyle_hh = .
qui replace pstyle_hh = pstyle_mom if (pstyle_mom==pstyle_dad) // same parenting style ornot 
*qui replace pstyle_hh = pstyle_mom if pstyle_dad==.
*qui replace pstyle_hh = pstyle_dad if pstyle_mom==.

label de pstyle_hh_labs 1 "Uninvolved" 2 "Permissive" 3 "Authoritarian" 4 "Authoritative"
label values pstyle_hh pstyle_hh_labs
label variable pstyle_hh "Household Parenting Style"


********************************* Table 4.2 ***********************************
gen countdummy=1
* count number of respondents in each hh education, respondent educ attainment, parenting style
collapse (count) countdummy, by(hh_edu redu_01 pstyle_hh)
bys hh_edu pstyle_hh: egen  r_all = total(countdummy)
* round: 
gen redu_percent = round(100*countdummy/r_all,0.01)
* display values for table: 
table redu_01 pstyle_hh  hh_edu ,  contents(mean redu_percent)
 
